[h5py] 15/455: Setup tweaks

Ghislain Vaillant ghisvail-guest at moszumanska.debian.org
Thu Jul 2 18:19:12 UTC 2015


This is an automated email from the git hooks/post-receive script.

ghisvail-guest pushed a commit to annotated tag 1.3.0
in repository h5py.

commit 25542edda96f491cc3e7a041f333f3fe700f04bf
Author: andrewcollette <andrew.collette at gmail.com>
Date:   Thu May 8 01:10:31 2008 +0000

    Setup tweaks
---
 h5py/h5.pyx |  6 +++++-
 setup.py    | 16 ++++++++++++----
 2 files changed, 17 insertions(+), 5 deletions(-)

diff --git a/h5py/h5.pyx b/h5py/h5.pyx
index d460f66..8c7274c 100755
--- a/h5py/h5.pyx
+++ b/h5py/h5.pyx
@@ -42,7 +42,11 @@ def _getversionastuple():
 
     return (major, minor, release)
     
-hdf5version = _getversionastuple()
+HDF5_VERS_TPL = _getversionastuple()
+HDF5_VERS = "%d.%d.%d" % HDF5_VERS_TPL
+
+API_VERS = '1.6'
+API_VERS_TPL = (1,6)
 
 def cycle():
     """ ()
diff --git a/setup.py b/setup.py
index 4f12c5a..a6459b3 100755
--- a/setup.py
+++ b/setup.py
@@ -60,9 +60,10 @@ NAME = 'h5py'
 VERSION = '0.1.0'
 REVISION = "$Rev: 0$"
 
-# If you have your HDF5 *.h files, etc somewhere not in /usr/include or
-# /usr/local/include, add that path here.
+# If you have your HDF5 *.h files and libraries somewhere not in /usr or
+# /usr/local, add that path here.
 custom_include_dirs = []    # = ["/some/other/path", "/an/other/path"]
+custom_library_dirs = []
 
 # === Custom extensions for distutils =========================================
 
@@ -183,14 +184,19 @@ pyx_src_path = 'h5py'
 pyx_extra_src = ['utils.c']         # C source files required for Pyrex code
 pyx_libraries = ['hdf5']            # Libraries to link into Pyrex code
 
 # Compile-time include dirs for Pyrex code
 pyx_include = [numpy.get_include()] 
 pyx_include.extend(['/usr/include', '/usr/local/include'])
 pyx_include.extend(custom_include_dirs)
+pyx_library_dirs = ['/usr/lib', '/usr/local/lib']
+pyx_library_dirs.extend(custom_library_dirs)
 
 # Additional compiler flags for Pyrex code
 pyx_extra_args = ['-Wno-unused', '-DH5_USE_16_API']
 
+extra_link_args = []
+extra_compile_args = pyx_extra_args
+
 
 # === Setup implementation ====================================================
 
@@ -206,7 +212,9 @@ for module_name in pyx_modules:
             sources, 
             include_dirs = pyx_include, 
             libraries = pyx_libraries,
-            extra_compile_args = pyx_extra_args
+            library_dirs = pyx_library_dirs, 
+            extra_compile_args = extra_compile_args,
+            extra_link_args = extra_link_args
         )
     )
 
@@ -183,14 +184,19 @@ pyx_src_path = 'h5py'
 pyx_libraries = ['hdf5']            # Libraries to link into Pyrex code
 
-# Compile-time include dirs for Pyrex code
+# Compile-time include and library dirs for Pyrex code
 pyx_include = [numpy.get_include()] 
 pyx_include.extend(['/usr/include', '/usr/local/include'])

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-science/packages/h5py.git



More information about the debian-science-commits mailing list